'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _theme = require('./theme');

var _theme2 = _interopRequireDefault(_theme);

var _radii = require('./util/radii');

var _radii2 = _interopRequireDefault(_radii);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

/**
 * A general purpose outline style button element with customizable colors
 */

var ButtonOutline = function ButtonOutline(_ref, _ref2) {
  var href = _ref.href;
  var big = _ref.big;
  var color = _ref.color;
  var children = _ref.children;
  var style = _ref.style;
  var className = _ref.className;

  var props = _objectWithoutProperties(_ref, ['href', 'big', 'color', 'children', 'style', 'className']);

  var rebass = _ref2.rebass;


  var config = _extends({}, _theme2.default, rebass);
  var customStyle = rebass ? rebass.ButtonOutline : {};
  var fontSizes = config.fontSizes;
  var bold = config.bold;
  var scale = config.scale;
  var colors = config.colors;
  var borderRadius = config.borderRadius;


  var Component = href ? 'a' : 'button';

  color = colors[color] || color || colors.primary;

  var sx = _extends({
    fontFamily: 'inherit',
    fontSize: fontSizes[5],
    fontWeight: bold,
    lineHeight: scale[2] + 'px',
    textDecoration: 'none',
    display: 'inline-block',
    margin: 0,
    padding: big ? scale[2] : scale[1] + 'px ' + scale[2] + 'px',
    cursor: 'pointer',
    border: 0,
    color: color,
    backgroundColor: 'transparent',
    boxShadow: 'inset 0 0 0 1px'
  }, customStyle, (0, _radii2.default)(props, borderRadius), style);

  return _react2.default.createElement(
    Component,
    _extends({}, props, {
      href: href,
      className: 'ButtonOutline',
      style: sx }),
    children
  );
};

ButtonOutline.propTypes = {
  /** Pass an href prop to make the ButtonOutline an <a> tag instead of a <button> */
  href: _react2.default.PropTypes.string,
  /** Text color */
  color: _react2.default.PropTypes.string,
  /** Controls the border radius for creating button groups */
  rounded: _react2.default.PropTypes.oneOfType([_react2.default.PropTypes.bool, _react2.default.PropTypes.oneOf(['top', 'right', 'bottom', 'left'])]),
  /** Creates a pill style button */
  pill: _react2.default.PropTypes.bool,
  /** Creates a larger button */
  big: _react2.default.PropTypes.bool
};

ButtonOutline.defaultProps = {
  rounded: true
};

ButtonOutline.contextTypes = {
  rebass: _react2.default.PropTypes.object
};

exports.default = ButtonOutline;